<?php

namespace App\Actions\Fortify;

use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Laravel\Fortify\Contracts\CreatesNewUsers;
use Laravel\Jetstream\Jetstream;

class CreateNewUser implements CreatesNewUsers
{
    use PasswordValidationRules;

    /**
     * Validate and create a newly registered user.
     *
     * @param  array<string, string>  $input
     */
    public function create(array $input): User
    {
        Validator::make($input, [
            'name' => ['required', 'string', 'max:255'],
            'username' => ['required', 'string', 'max:255', 'unique:users'],
            'email' => ['required', 'string', 'email', 'max:255', 'unique:users'],
            'password' => $this->passwordRules(),
            'terms' => Jetstream::hasTermsAndPrivacyPolicyFeature() ? ['accepted', 'required'] : '',
        ], [
            'required'  => __(':attribute field is required.'),
            'string'    => __(':attribute field must contain only letters.'),
            'unique'    => __(':attribute must be unique, please try a different :attribute.'),
            'max'       => __(':attribute field must contain at most :max characters.'),
            'min'       => __(':attribute field must contain at least :min characters.'),
            'email'     => __(':attribute field should be email.'),
            'confirmed' => __(':attribute fields do not match.')
        ], [
            'name'      => __('Full Name'),
            'username'  => __('Username'),
            'email'     => __('Email'),
            'password'  => __('Password'),
            'terms'     => __('Terms')
        ])->validate();

        return User::create([
            'name' => $input['name'],
            'username' => $input['username'],
            'email' => $input['email'],
            'password' => Hash::make($input['password']),
        ]);
    }
}
