<?php

namespace App\Http\Middleware;

use Closure;
use GuzzleHttp\Client;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\App;
use Illuminate\Support\Facades\Cache;
use Symfony\Component\HttpFoundation\Response;

class SetLanguageByLocation
{
    /**
     * Handle an incoming request.
     *
     * @param  \Closure(\Illuminate\Http\Request): (\Symfony\Component\HttpFoundation\Response)  $next
     */
    public function handle(Request $request, Closure $next): Response
    {

        $userIp = $request->ip();

        $cacheKey = 'location_' . $userIp;

        $userLocation = Cache::get($cacheKey);

        if (!$userLocation) {
            $userLocation = $this->getUserLocation($userIp);
            Cache::put($cacheKey, $userLocation, now()->addDays(1));
        }

        if ($userLocation === 'Turkey') {
            App::setLocale('tr');
        } else {
            App::setLocale('en');
        }
        return $next($request);
    }

    protected function getUserLocation($userIp){

        $client = new Client();
        $response = $client->get("https://ipinfo.io/{$userIp}?token=" . env('IPINFO_TOKEN'));

        $data = json_decode($response->getBody());

        if(isset($data->country) && $data->country == "TR"){
            return "Turkey";
        }else{
            return "Worldwide";
        }
    }
}
