<?php

namespace App\Livewire\Dashboard;

use App\Models\Category as ModelsCategory;
use Illuminate\Support\Facades\Cache;
use Livewire\Component;

class Category extends Component{

    public $title;
    public $description;

    public $activeToggle = false;

    public function toggle(){
        $this->activeToggle = $this->activeToggle ? false: true;
    }

    public function setContent($value){
        $this->description = $value;
    }

    public function delete($id){
        if($id == 1){
            return redirect()->back()->with('error', __('Default category can\'t be deleted.'));
        }else{
            $category = ModelsCategory::find($id);
            $category->threads()->update(['category_id' => 1]);
            $category->delete();
        }
    }

    public function add(){
        $this->validate([
            'title'         => 'required|min:3',
            'description'   => 'required'
        ], [
            'required'      => __(':attribute field is required.')
        ], [
            'title'         => __('Title'),
            'description'   => __('Content')
        ]);

        ModelsCategory::create([
            'title'         => $this->title,
            'description'   => $this->description
        ]);

        $this->title = '';
        $this->description = '';
        $this->activeToggle = false;
    }

    public function render(){
        $categories = ModelsCategory::paginate(20);

        $categoryCount = Cache::remember('categoryCount', now()->addMinutes(60), function(){
            return ModelsCategory::count();
        });

        $categoryCount = Cache::get('categoryCount');

        return view('livewire.dashboard.category', compact('categories', 'categoryCount'))->title(__('Categories'));
    }
}
