<?php

namespace App\Livewire\Dashboard;

use App\Models\User;
use Livewire\Component;
use Livewire\WithFileUploads;

class EditUser extends Component
{

    use WithFileUploads;

    public $id;
    public $avatar;

    // General
    public $name;
    public $username;
    public $about;
    public $email;
    public $location;
    public $website;
    public $job;

    public $type;

    public function mount($id){
        $this->id = $id;

        $user = User::findOrFail($id);
        $this->name = $user->name;
        $this->username = $user->username;
        $this->email = $user->email;

        $this->about = $user->getMeta('about');
        $this->location = $user->getMeta('location');
        $this->website = $user->getMeta('website');
        $this->job = $user->getMeta('job');

        $this->type = $user->type;
    }

    /**
     * Upload Avatar
     *
     * @return void
     */
    public function uploadAvatar(){

        $this->validate([
            'avatar'    => 'image|max:1024'
        ]);

        $this->avatar->storeAs('profile-photos', $this->avatar->getFileName(), 'public');

        // Upload
        $user = User::find($this->id);
        $user->profile_photo_path = $this->avatar->getFileName();
        $user->save();

        return redirect()->back();
    }

    public function general(){
        $this->validate([
            'name'          => 'required|min:3',
            'username'      => 'required|min:3|unique:users,username,' . $this->id,
            'website'       => 'nullable|url:http,https',
            'email'         => 'required|email:rfc,dns'
        ], [
            'required'      => __(':attribute field is required.'),
            'min'           => __(':attribute field must contain at least :min characters.'),
            'unique'        => __(':attribute must be unique, please try a different :attribute.'),
            'url'           => __(':attribute field must be an URL.'),
            'email'         => __(':attribute field should be email.')
        ], [
            'name'          => __('Full Name'),
            'username'      => __('Username'),
            'website'       => __('Website'),
            'email'         => __('Email')
        ]);

        $user           = User::find($this->id);

        $user->name     = $this->name;
        $user->username = $this->username;
        $user->email    = $this->email;
        $user->save();

        // Metas
        $user->setMeta('about', $this->about ?? '');
        $user->setMeta('location', $this->location ?? '');
        $user->setMeta('website', $this->website ?? '');
        $user->setMeta('job', $this->job ?? '');

        return redirect()->back()->with('success',  __('Your account settings have been successfully updated.'));
    }

    public function render(){
        $user = User::find($this->id);
        return view('livewire.dashboard.edit-user', compact('user'))->title(__('Edit User'));
    }
}
