<?php

namespace App\Livewire\Dashboard;

use App\Models\Analytic;
use App\Models\Job;
use App\Models\Thread;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;

class Index extends Component
{
    public function render(){
        $last30Days = Carbon::now()->subDays(30);
        $thread_analytics = Analytic::where(['user_id' => Auth::id(), 'type' => 'thread'])
        ->where('created_at', '>=', $last30Days)
        ->selectRaw('target_id, SUM(views_count) as total_views_count')
        ->groupBy('target_id')
        ->orderBy('total_views_count', 'desc')
        ->take(10)
        ->get();

        $job_analytics = Analytic::where(['user_id' => Auth::id(), 'type' => 'job'])
        ->where('created_at', '>=', $last30Days)
        ->selectRaw('target_id, SUM(views_count) as total_views_count')
        ->groupBy('target_id')
        ->orderBy('total_views_count', 'desc')
        ->take(10)
        ->get();

        $best_threads = Thread::where(['user_id' => Auth::id()])
        ->orderBy('views_count', 'desc')
        ->take(10)
        ->get();

        $best_jobs = Job::where(['user_id' => Auth::id()])
        ->orderBy('views_count', 'desc')
        ->take(10)
        ->get();

        return view('livewire.dashboard.index', compact('thread_analytics', 'job_analytics', 'best_threads', 'best_jobs'))->title(__('Analytics'));
    }
}
