<?php

namespace App\Livewire\Dashboard;

use App\Models\Setting;
use Livewire\Component;
use Livewire\WithFileUploads;

class Settings extends Component
{

    use WithFileUploads;

    public $sitename;
    public $sitedescription;
    public $sitelanguage;
    public $sitefavicon;

    public $favicon;

    public function mount(){
        $this->sitename = get_setting('site_title');
        $this->sitedescription = get_setting('site_description');
        $this->sitelanguage = get_setting('site_language');
        $this->sitefavicon = get_setting('site_favicon');
    }

    public function uploadFavicon(){
        $this->validate([
            'favicon'    => 'image|max:1024'
        ]);

        $this->favicon->storeAs('favicon', $this->favicon->getFileName(), 'public');

        set_setting('site_favicon', $this->favicon->getFileName());

        return redirect()->back()->with('success', __('Favicon has been successfully uploaded.'));
    }

    public function updateSettings(){

        $this->validate([
            'sitename'         => 'required',
            'sitedescription'   => 'required',
            'sitelanguage'      => 'required'
        ], [
            'required'          => __(':attribute field is required.')
        ], [
            'sitename'         => __('Site Title'),
            'sitedescription'   => __('Site Description'),
            'sitelanguage'      => __('Site Language')
        ]);

        set_setting('site_title', $this->sitename);
        set_setting('site_description', $this->sitedescription);
        set_setting('site_language', $this->sitelanguage);

        return redirect()->back()->with('success', __('Site settings has been successfully updated!'));
    }

    public function render()
    {
        return view('livewire.dashboard.settings')->title(__('Settings'));
    }
}
