<?php

namespace App\Livewire\Dashboard;

use App\Models\Notification;
use App\Models\Subscription;
use App\Models\User;
use Illuminate\Support\Facades\Cache;
use Livewire\Component;
use Livewire\WithPagination;

class Users extends Component
{

    use WithPagination;

    public $premium;

    /**
     * Ban User
     */
    public function ban($id){
        $user = User::find($id);

        if($user->type != "admin"){
            if($user->type == "banned"){
                $user->type = "user";
                $message = __('User\'s ban has been successfully removed.');
            }else{
                $user->type = "banned";
                $message = __('User has been successfully banned.');
            }
            $user->save();

            return redirect()->back()->with('success', $message);
        }else{
            return redirect()->back()->with('error', __('You can\'t ban the admin.'));
        }
    }

    public function delete($id){
        $user = User::find($id);
        if($user->type != "admin"){
            $user->delete();
            $user->threads()->delete();
            $user->comments()->delete();
            $user->meta()->delete();
            $user->favorites()->delete();
            $user->jobs()->delete();
            $user->followers()->delete();
            $user->followings()->delete();

            Notification::where('sender_id', $id)->delete();

            return redirect()->back()->with('success', __('User has been successfully deleted.'));
        }else{
            return redirect()->back()->with('error', __('You can\'t delete the admin'));
        }
    }

    public function changePremium($id){
        $subscription = Subscription::where('user_id', $id);

        if($this->premium == "free" && $subscription->exists()){
            $subscription->delete();
            return redirect()->back()->with('success', __('Successfully downgraded to free plan.'));
        }else{
            $subscription->delete();
            if($this->premium == "1yr"){
                $expiration = now()->addDays(365);
            }else{
                $expiration = now()->addDays(30);
            }
            Subscription::create([
                'user_id'           => $id,
                'expiration_date'   => $expiration
            ]);

            return redirect()->back()->with('success', __('Subscription plan has been changed successfully.'));
        }
    }

    public function render(){
        $users = User::orderBy('created_at', 'desc')->paginate(10);

        $usersCount = Cache::remember('usersCount', now()->addMinutes(60), function () {
            return User::count();
        });

        $usersCount = Cache::get('usersCount');

        return view('livewire.dashboard.users', compact('users', 'usersCount'))->title(__('Users'));
    }
}
