<?php

namespace App\Livewire;

use App\Models\Job;
use App\Models\JobCategory;
use Illuminate\Support\Facades\Cache;
use Livewire\Component;
use Livewire\WithPagination;

class Jobs extends Component
{

    use WithPagination;

    public $sortText;
    public $sort;
    public $budget = [];
    public $updateCategories = [];
    public $searchText;
    public $paginationNumber = 20;

    public function mount(){
        $this->sortText = __('Newest');
        $this->sort = 'desc';
    }

    public function loadMore(){
        $this->paginationNumber += 20;
    }

    public function filter(){
        $this->render();
    }

    public function setOrder($order){
        if($order == "oldest"){
            $this->sortText = __('Oldest');
            $this->sort = "asc";
        }else{
            $this->sortText = __('Newest');
            $this->sort = "desc";
        }

        $this->render();
    }

    public function render(){

        $budgetRanges = $this->budget;

        $jobsQuery = Job::where('status', 1);

        if (count($this->updateCategories) > 0) {
            $jobsQuery->whereIn('category_id', $this->updateCategories);
        }

        // if (in_array('over_30000', $budgetRanges)) {
        //     $jobsQuery->orWhere('budget', '>', 30000);
        // } else {
        //     foreach ($budgetRanges as $range) {
        //         [$min, $max] = explode('-', $range);
        //         $jobsQuery->orWhereBetween('budget', [$min, $max]);
        //     }
        // }

        if($this->budget){
            $jobsQuery->where(function ($query) use ($budgetRanges) {
                if(in_array('over_30000', $budgetRanges)){
                    $query->orWhere('budget', '>', 30000);
                }else{
                    foreach ($budgetRanges as $range) {
                        [$min, $max] = explode('-', $range);
                        $query->orWhereBetween('budget', [$min, $max]);
                    }
                }
            });
        }

        if ($this->searchText) {
            $jobsQuery->where(function ($query) {
                $query->where('title', 'LIKE', '%' . $this->searchText . '%')
                    ->orWhere('content', 'LIKE', '%' . $this->searchText . '%');
            });
        }

        $jobs = $jobsQuery->orderBy('featured', 'desc')
            ->orderBy('created_at', $this->sort)
            ->cursorPaginate($this->paginationNumber);

        $jobsCount = Cache::remember('jobsCount', now()->addMinutes(60), function () {
            return Job::count();
        });

        $job_categories = Cache::remember('job_categories', now()->addMinutes(120), function(){
            return JobCategory::get();
        });

        return view('livewire.jobs', [
            'jobs'  => $jobs,
            'jobsCount' => $jobsCount,
            'job_categories' => $job_categories
        ])->title(__('Jobs'));
    }
}
