<?php

namespace App\Livewire\Jobs;

use App\Models\Analytic;
use App\Models\Job;
use App\Models\JobApplication;
use Carbon\Carbon;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;

class Single extends Component{

    public $slug;
    public $job_id;
    public $cat_id;

    public $modelTime;
    public $modelContent;

    public $active = false;

    public $applicants_count = 0;

    public function mount($slug){
        $this->cat_id = Job::where([
            'slug'      => $this->slug,
            'status'    => 1
        ])->first()->category_id;

        $this->slug = $slug;

        $this->job_id =  Job::where([
            'slug'      => $this->slug,
            'status'    => 1
        ])->first()->id;

        $check = JobApplication::where([
            'user_id'   => Auth::id(),
            'job_id'    => $this->job_id
        ]);

        if($check->exists()){
            $this->active = true;
        }

        $this->applicants_count = JobApplication::where('job_id', $this->job_id)->count();
    }

    public function apply(){

        $this->validate([
            'modelTime'     => 'required|integer',
            'modelContent'  => 'required|min:10'
        ], [
            'required'  => __(':attribute field is required.'),
            'integer'   => __(':attribute field must contain only numbers.'),
            'min'       => __(':attribute field must contain at least :min characters.')
        ], [
            'modelTime'     => __('Estimated Delivery Time'),
            'modelContent'  => __('Content')
        ]);

        $check = JobApplication::where([
            'user_id'   => Auth::id(),
            'job_id'    => $this->job_id
        ]);

        if($check->exists()){
            $this->active = true;
        }else{
            JobApplication::create([
                'user_id'   => Auth::id(),
                'job_id'    => $this->job_id,
                'day'       => $this->modelTime,
                'content'   => $this->modelContent
            ]);

            return redirect()->route('jobs.single', $this->slug)->with('success', __('You have successfully applied for the posting.'));
        }
    }

    public function render(){
        $job = Job::where([
            'slug'      => $this->slug,
            'status'    => 1
        ])->firstOrFail();

        $related_jobs = Job::where([
            'category_id'   => $this->cat_id,
            'status'        => 1,
            'featured'      => 0
        ])
        ->where('id', '<>', $job->id)
        ->take(5)
        ->get();

        $job_applicants = JobApplication::where('job_id', $this->job_id)->paginate(10);

        $job->increment('views_count');

        $today = Carbon::now()->format('Y-m-d');

        $analytic = Analytic::where(['target_id' => $job->id, 'type' => 'job'])->whereDate('created_at', $today);

        if($analytic->exists()){
            $analytic->increment('views_count');
        }else{
            $createAnalytic = Analytic::create([
                'target_id' => $job->id,
                'user_id'   => $job->user->id,
                'type'      => 'job'
            ]);

            $createAnalytic->increment('views_count');
        }

        return view('livewire.jobs.single', compact('job', 'related_jobs', 'job_applicants'))->title($job->title);
    }
}
