<?php

namespace App\Livewire\Thread;

use App\Models\CommentLike;
use App\Models\Thread;
use Illuminate\Support\Facades\Auth;
use Livewire\Attributes\Rule;
use Livewire\Component;
use App\Models\Comment as ModelsComment;
use App\Models\Notification;

class Comment extends Component
{

    public $id;
    public $threadId;
    public $comment;
    public $likeCount;
    public $active = false;
    public $content;
    public $userId;

    public function mount(){
        $like_check = CommentLike::where('comment_id', $this->id)->where('user_id', Auth::id())->first();
        if($like_check){
            $this->active = true;
        }
        $this->likeCount = CommentLike::where('comment_id', $this->id)->count();

        $this->userId = ModelsComment::where('id', $this->id)->first()->user_id;
    }

    public function like($id){
        if(Auth::check()){
            $commentcheck = ModelsComment::find($this->id);
            if(Auth::id() != $commentcheck->user_id){
                $like_check = CommentLike::where('comment_id', $id)->where('user_id', Auth::id())->first();

                if($like_check){
                    CommentLike::where('comment_id', $id)
                        ->where('user_id', Auth::id())
                        ->delete();
                    $this->active = false;

                    Notification::where([
                        'sender_id'   => Auth::id(),
                        'user_id'       => $this->userId,
                        'target_id'     => $this->threadId,
                        'type'      => 'comment_like'
                    ])->delete();
                }else{
                    CommentLike::create([
                        'comment_id'    => $id,
                        'user_id'       => Auth::id()
                    ]);
                    $this->active = true;

                    Notification::create([
                        'sender_id'   => Auth::id(),
                        'user_id'       => $this->userId,
                        'target_id'     => $this->threadId,
                        'type'      => 'comment_like',
                        'read'      => 0
                    ]);
                }

                $this->likeCount = CommentLike::where('comment_id', $id)->count();
            }
        }else{
            $this->dispatch('not-login');
        }
    }

    public function add(){
        if(Auth::check()){
            $this->validate([
                'content' => 'required|min:4'
            ], [
                'required' => __(':attribute field is required.'),
                'min'       => __(':attribute field must contain at least :min characters.')
            ], [
                'content'   => __('Content')
            ]);

            $thread = Thread::find($this->threadId);

            if(Auth::id() != $thread->user->id){
                Notification::create([
                    'sender_id' => Auth::id(),
                    'user_id'   => $thread->user->id,
                    'target_id'     => $this->threadId,
                    'type'      => 'thread_comment',
                    'read'      => 0
                ]);
            }

            $comment_ex = ModelsComment::find($this->id);

            if($comment_ex->user_id != Auth::id()){
                Notification::create([
                    'sender_id' => Auth::id(),
                    'user_id'   => $comment_ex->user_id,
                    'target_id'     => $this->threadId,
                    'type'      => 'comment_reply',
                    'read'      => 0
                ]);
            }

            ModelsComment::create([
                'thread_id'     => $this->threadId,
                'user_id'       => Auth::id(),
                'content'       => $this->content,
                'comment_id'    => $this->id
            ]);

            $this->content = '';
        }else{
            $this->dispatch('not-login');
        }
    }

    public function destroy($id){
        $comment = ModelsComment::where('id', $id)->first();
        if(Auth::user()->type == "admin" || Auth::id() == $comment->user->id){
            $comment->replies()->delete();
            $comment->delete();
            $this->dispatch('refreshPage');
        }
    }

    public function render(){
        return view('livewire.thread.comment');
    }
}
