<?php

namespace App\Livewire\Thread;

use App\Models\Comment;
use App\Models\Notification;
use Livewire\WithPagination;
use Livewire\Component;
use App\Models\Thread;
use Illuminate\Support\Facades\Auth;
use Livewire\Attributes\On;

class Comments extends Component
{

    use WithPagination;

    public $id;
    public $content;

    public $comments;
    public $commentCount;

    protected $listeners = ['loadMore', 'refreshComments', 'refreshJS'];

    public function mount(){
        $thread = Thread::where('id', $this->id)->first();
        $this->comments = $thread->comments()->where('comment_id', '=', NULL)->orderBy('created_at', 'desc')->take(5)->get();
        $this->commentCount = $thread->comments()->where('comment_id', '=', NULL)->count();
    }

    public function save(){
        if(Auth::check()){

            $this->validate([
                'content'   => 'required|min:5'
            ], [
                'required'  => __(':attribute field is required.')
            ], [
                'content'   => __('Content')
            ]);

            Comment::create([
                'content' => $this->content,
                'user_id'   => Auth::id(),
                'thread_id' => $this->id
            ]);

            $this->content = '';

            $thread = Thread::find($this->id);
            $thread->updated_at = now();
            $thread->save();

            if(Auth::id() != $thread->user->id){
                Notification::create([
                    'sender_id' => Auth::id(),
                    'user_id'   => $thread->user->id,
                    'target_id' => $this->id,
                    'type'      => 'thread_comment',
                    'read'       => 0
                ]);
            }

            $this->mount();
        }else{
            $this->dispatch('not-login');
        }
    }

    public function loadMore(){
        $thread = Thread::where('id', $this->id)->first();
        $newComments = $thread->comments()->where('comment_id', '=', NULL)->orderBy('created_at', 'desc')->skip(count($this->comments))->take(5)->get();
        $this->comments = $this->comments->concat($newComments);
        $this->dispatch('refreshJS');
    }

    public function render(){
        return view('livewire.thread.comments', [
            'comments' => $this->comments
        ]);
    }
}
