<?php

namespace App\Livewire\Thread;

use App\Models\Analytic;
use App\Models\Category;
use App\Models\Thread;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;

use Livewire\Attributes\Rule;

class Create extends Component
{

    public $title;
    public $content;
    public $category;

    public function save(){
        $this->validate([
            'title'     => 'required|min:10',
            'content'   => 'required|min:10',
            'category'  => 'required'
        ], [
            'required'  => __(':attribute field is required.'),
            'min'       => __(':attribute field must contain at least :min characters.')
        ], [
            'title'     => __('Title'),
            'content'   => __('Content'),
            'category'  => __('Category')
        ]);

        $thread = Thread::create([
            'title'         => $this->title,
            'content'       => $this->content,
            'category_id'   => $this->category,
            'user_id'       => Auth::id(),
            'status'        => 'published'
        ]);

        return $this->redirect(route('thread', $thread->slug));
    }

    public function setContent($value){
        $this->content = $value;
    }

    public function render()
    {
        $categories = Category::all();
        return view('livewire.thread.create', compact('categories'))->title(__('Create Post'));
    }
}
