<?php

namespace App\Livewire\User;

use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Validator;
use Illuminate\Validation\Rule as ValidationRule;
use Livewire\Attributes\Rule;
use Livewire\Component;
use Livewire\WithFileUploads;

class EditProfile extends Component{

    use WithFileUploads;

    public $avatar;

    // General
    public $name;
    public $username;
    public $about;
    public $location;
    public $website;
    public $job;

    public function mount(){
        $user = User::where('id', Auth::id())->firstOrFail();
        $this->name = $user->name;
        $this->username = $user->username;

        // $this->email = $user->email;

        // $this->about = $user->getMeta('about');
        // $this->location = $user->getMeta('location');
        // $this->website = $user->getMeta('website');
        // $this->job = $user->getMeta('job');
        $this->about        = user_get_meta('about', $user->id);
        $this->location     = user_get_meta('location', $user->id);
        $this->website      = user_get_meta('website', $user->id);
        $this->job          = user_get_meta('job', $user->id);
    }

    /**
     * Upload Avatar
     *
     * @return void
     */
    public function uploadAvatar(){

        $this->validate([
            'avatar'    => 'image|max:1024'
        ]);

        $this->avatar->storeAs('profile-photos', $this->avatar->getFileName(), 'public');

        // Upload
        $user = User::find(Auth::id());
        $user->profile_photo_path = $this->avatar->getFileName();
        $user->save();

        return redirect()->route('edit-profile.index');
    }

    public function general(){
        $this->validate([
            'name'          => 'required|min:3',
            'username'      => 'required|min:3|unique:users,username,' . Auth::id(),
            'website'       => 'url:http,https'
        ], [
            'required'      => __(':attribute field is required.'),
            'min'           => __(':attribute field must contain at least :min characters.'),
            'unique'        => __(':attribute must be unique, please try a different :attribute.'),
            'url'           => __(':attribute field must be an URL.')
        ], [
            'name'          => __('Full Name'),
            'username'      => __('Username'),
            'website'       => __('Website')
        ]);

        $user           = User::find(Auth::id());

        $user->name     = $this->name;
        $user->username = $this->username;
        // $user->email    = $this->email;
        $user->save();

        // Metas
        // $user->setMeta('about', $this->about ?? '');
        // $user->setMeta('location', $this->location ?? '');
        // $user->setMeta('website', $this->website ?? '');
        // $user->setMeta('job', $this->job ?? '');

        user_set_meta('about', $this->about ?? '', $user->id);
        user_set_meta('location', $this->location ?? '', $user->id);
        user_set_meta('website', $this->website ?? '', $user->id);
        user_set_meta('job', $this->job ?? '', $user->id);

        return redirect()->route('edit-profile.index')->with('success',  __('Your account settings have been successfully updated.'));
    }

    // public function changePassword(){
    //     Validator::make(
    //         ['oldpassword' => $this->oldpassword, 'password' => $this->password, 'password_confirmation' => $this->password_confirmation],
    //         ['oldpassword' => 'required', 'password' => 'required|confirmed|min:8']
    //     )->validate();

    //     if(!Hash::check($this->oldpassword, Auth::user()->password)){
    //         return back()->with('error', 'Eski şifre doğru değil!');
    //     }else{
    //         User::where('id', Auth::id())->update([
    //             'password'  => Hash::make($this->password)
    //         ]);

    //         $this->oldpassword = '';
    //         $this->password = '';
    //         $this->password_confirmation = '';

    //         return back()->with('success', 'Şifre başarıyla değiştirildi!');
    //     }
    // }

    public function render(){
        $user = User::where('id', Auth::id())->firstOrFail();
        return view('livewire.user.edit-profile', compact('user'))->title(__('Account Settings'));
    }
}
