<?php

namespace App\Livewire\User\EditProfile;

use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Facades\Redirect;
use Livewire\Component;

class Email extends Component{

    public $email;
    public $password;

    public function mount(){
        $this->email = User::find(Auth::id())->email;
    }

    public function changeMail(){

        $this->validate([
            'email' => 'required|email:rfc,dns|unique:users,email,' . Auth::id(),
            'password'  => 'required'
        ], [
            'required'  => __(':attribute field is required.'),
            'email'     => __(':attribute field should be email.'),
            'unique'    => __(':attribute must be unique, please try a different :attribute.')
        ], [
            'email'     => __('Email'),
            'password'  => __('Şifre')
        ]);


        if(!Hash::check($this->password, Auth::user()->password)){
            // return Redirect::back()->with('error', __('Your current password is not correct.'));
            return redirect()->route('edit-profile.email')->with('error',  __('Your current password is not correct.'));
        }else{
            $user = User::find(Auth::id());
            $user->email = $this->email;
            $user->save();
            return redirect()->route('edit-profile.email')->with('success', __('Your e-mail address has been successfully updated.'));
        }
    }

    public function render(){
        $user = User::find(Auth::id());
        return view('livewire.user.edit-profile.email', compact('user'))->title(__('Email Settings'));
    }
}
