<?php

namespace App\Livewire\User\EditProfile;

use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Hash;
use Livewire\Component;

class Password extends Component{

    public $current_password;
    public $password;
    public $password_confirmation;

    public function changePassword(){
        $this->validate([
            'current_password'  => 'required',
            'password'          => 'required|min:6|confirmed'
        ], [
            'required'          => __(':attribute field is required.'),
            'min'               => __(':attribute field must contain at least :min characters.'),
            'confirmed'         => __('Password and repeat password do not match.')
        ], [
            'current_password'  => __('Current Password'),
            'password'          => __('Password')
        ]);

        if(!Hash::check($this->password_confirmation, Auth::user()->password)){
            return redirect()->route('edit-profile.password')->with('error', __('Your current password is not correct!'));
        }else{
            User::where('id', Auth::id())->update([
                'password'  => Hash::make($this->password)
            ]);

            $this->current_password = '';
            $this->password = '';
            $this->password_confirmation = '';

            return redirect()->route('edit-profile.password')->with('success', __('Password successfully changed!'));
        }
    }

    public function render()
    {
        return view('livewire.user.edit-profile.password')->title(__('Password Settings'));
    }
}
