<?php

namespace App\Livewire\User;

use App\Models\Following;
use App\Models\Message;
use App\Models\Notification;
use App\Models\User;
use Illuminate\Support\Facades\Auth;
use Livewire\Component;
use Livewire\WithPagination;

class Profile extends Component{

    use WithPagination;

    public $username;
    public $user;
    public $following = false;

    public $title;

    public function mount($username){
        $this->username = $username;

        $this->user = User::where('username', $this->username)->firstorFail();
        $following = Following::where('user_id', Auth::id())->where('following_id', $this->user->id)->first();

        if($following){
            $this->following = true;
        }else{
            $this->following = false;
        }

        $this->title = $this->user->name;

    }

    public function sendMessage(){
        if(Auth::check()){
            $exists = Message::where(function($query){
                $query->where('sender_id', Auth::id())
                    ->where('recivier_id', $this->user->id);
            })->orWhere(function($query){
                $query->where('sender_id', $this->user->id)
                    ->where('recivier_id', Auth::id());
            })->first();

            if($exists){
                return redirect()->route('messages.view', $exists->id);
            }else{
                $created = Message::create([
                    'sender_id' => Auth::id(),
                    'recivier_id' => $this->user->id
                ]);
            }

            return redirect()->route('messages.view', $created->id);
        }else{
            $this->dispatch('not-login');
        }
    }

    public function follow(){
        if(Auth::check()){
            $following = Following::where('user_id', Auth::id())->where('following_id', $this->user->id)->first();
            if($following){
                Following::where('user_id', Auth::id())
                    ->where('following_id', $this->user->id)
                    ->delete();

                $this->following = false;

                $noti = Notification::where([
                    'sender_id' => Auth::id(),
                    'user_id'   => $this->user->id,
                    'type'      => 'follow'
                ]);

                if($noti->exists()){
                    $noti->delete();
                }
            }else{
                Following::create([
                    'user_id'       => Auth::id(),
                    'following_id'  => $this->user->id
                ]);
                $this->following = true;

                Notification::create([
                    'sender_id' => Auth::id(),
                    'user_id'   => $this->user->id,
                    'type'      => 'follow'
                ]);
            }

        }else{
            $this->dispatch('not-login');
        }
    }

    public function render(){
        $user = User::where('username', $this->username)->firstorFail();
        $threads = $user->threads()->orderBy('updated_at', 'desc')->paginate(10);

        Notification::where(['user_id' => Auth::id(), 'type' => 'follow'])->update(['read' => 1]);

        return view('livewire.user.profile', compact('user', 'threads'))->title($this->title);
    }
}
