<?php

namespace App\Models;

use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Database\Eloquent\Model;
use App\Models\User;
use App\Models\Category;
use App\Models\Comment;

use Cviebrock\EloquentSluggable\Sluggable;

class Thread extends Model
{
    use HasFactory;
    use Sluggable;

    protected $fillable = ['title', 'slug', 'content', 'user_id', 'category_id', 'status'];

    public function sluggable(): array{
        return [
            'slug' => [
                'source'    => 'title'
            ]
        ];
    }

    public function user(){
        return $this->belongsTo(User::class);
    }

    public function category(){
        return $this->belongsTo(Category::class);
    }

    public function comments(){
        return $this->hasMany(Comment::class, 'thread_id', 'id')->latest('created_at');
    }

    public function scopeWithCommentsAndReplies($query){
        return $query->with('comments.replies')->orderByDesc('created_at');
    }

    public function likes(){
        return $this->hasMany(Like::class);
    }

    // public function analytics(){
    //     return $this->morphMany(Analytic::class, 'target');
    // }
}
