<?php

namespace App\Models;

// use Illuminate\Contracts\Auth\MustVerifyEmail;
use Illuminate\Database\Eloquent\Factories\HasFactory;
use Illuminate\Foundation\Auth\User as Authenticatable;
use Illuminate\Notifications\Notifiable;
use Illuminate\Support\Facades\Auth;
use Laravel\Fortify\TwoFactorAuthenticatable;
use Laravel\Jetstream\HasProfilePhoto;
use Laravel\Sanctum\HasApiTokens;

class User extends Authenticatable
{
    use HasApiTokens;
    use HasFactory;
    use HasProfilePhoto;
    use Notifiable;
    use TwoFactorAuthenticatable;

    /**
     * The attributes that are mass assignable.
     *
     * @var array<int, string>
     */
    protected $fillable = [
        'name',
        'username',
        'email',
        'password',
        'about'
    ];

    /**
     * The attributes that should be hidden for serialization.
     *
     * @var array<int, string>
     */
    protected $hidden = [
        'password',
        'remember_token',
        'two_factor_recovery_codes',
        'two_factor_secret',
    ];

    /**
     * The attributes that should be cast.
     *
     * @var array<string, string>
     */
    protected $casts = [
        'email_verified_at' => 'datetime',
    ];

    // public static $enums = [
    //     'thread_like'   => __('Konu Beğeni'),
    //     'comment_like'  => __('Yorum Beğeni'),
    //     'reply_like'    => __('Cevap Beğeni'),
    //     'thread_comment'=> __('Konu Yorumu'),
    //     'follow'        => __('Takip')
    // ];

    /**
     * The accessors to append to the model's array form.
     *
     * @var array<int, string>
     */
    protected $appends = [
        'profile_photo_url',
    ];

    public function threads(){
        return $this->hasMany(Thread::class);
    }

    public function comments(){
        return $this->hasMany(Comment::class);
    }

    public function followers(){
        return $this->hasMany(Following::class, 'following_id', 'id');
    }

    public function followings(){
        return $this->hasMany(Following::class, 'user_id', 'id');
    }

    public function meta(){
        return $this->hasOne(UserMeta::class, 'user_id');
    }

    public function getMeta($name){
        $meta = $this->meta;
        if ($meta) {
            $meta = $meta->where('name', $name)->first();
            return $meta ? $meta->value : null;
        }

        return null;
    }

    public function setMeta($name, $value){
        $meta = $this->meta()->where('name', $name)->first();

        if ($meta) {
            $meta->value = $value;
            $meta->save();
        } else {
            $this->meta()->create([
                'name' => $name,
                'value' => $value
            ]);
        }
    }

    public function subscription(){
        return $this->hasOne(Subscription::class);
    }

    public function favorites(){
        return $this->belongsToMany(Thread::class, 'favorites', 'user_id', 'thread_id');
    }

    public function jobs(){
        return $this->hasMany(Job::class);
    }
}
