<?php

namespace App\Providers;

use App\Models\Category;
use App\Models\Following;
use App\Models\Message;
use App\Models\Notification;
use App\Models\Setting;
use App\Models\Thread;
use App\Models\User;
use Carbon\Carbon;

use Illuminate\Support\Collection;
use Illuminate\Pagination\LengthAwarePaginator;
use Illuminate\Routing\Router;
use Illuminate\Support\Facades\Auth;
use Illuminate\Support\Facades\Cache;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Request;
use Illuminate\Support\Facades\Route;
use Illuminate\Support\ServiceProvider;

use Illuminate\Support\Facades\View;

class AppServiceProvider extends ServiceProvider
{
    /**
     * Register any application services.
     */
    public function register(): void
    {
        //
    }

    /**
     * Bootstrap any application services.
     */
    public function boot(): void
    {

        Carbon::setLocale(config('app.locale'));

        // Collection::macro('paginate', function($perPage, $total = null, $page = null, $pageName = 'page'): LengthAwarePaginator {
        //     $page = $page ?: LengthAwarePaginator::resolveCurrentPage($pageName);

        //     return new LengthAwarePaginator(
        //         $this->forPage($page, $perPage)->values(),
        //         $total ?: $this->count(),
        //         $perPage,
        //         $page,
        //         [
        //             'path' => LengthAwarePaginator::resolveCurrentPath(),
        //             'pageName' => $pageName,
        //         ]
        //     );
        // });

        Router::macro('isWith', function ($name, $parameters) {
            return url()->current() === route($name, $parameters);
        });

        if (!$this->checkDatabaseConfiguration()) {
            if (!Request::is('install*')) {
                echo redirect('install');
                die;
            }
        } else {
            view()->composer('*', function ($view) {
                $users = Cache::remember('users', now()->addSeconds(10), function () {
                    return User::where('type', '!=', 'banned')
                        ->where('id', '<>', Auth::check() ? Auth::user()->id : 0)
                        ->inRandomOrder()
                        ->limit(5)
                        ->get();
                });

                $usersCount = Cache::remember('usersCount', now()->addMinutes(60), function () {
                    return User::count();
                });

                $usersCount = Cache::get('usersCount');

                $categories = Category::withCount('threads')->orderBy('threads_count', 'desc')->get(5);

                $all_categories = Category::orderBy('title', 'desc')->get();

                $users = Cache::get('users');

                if (Auth::check()) {
                    $unreadMessageCount = Message::where(function ($query) {
                        $query->where('recivier_id', Auth::id())
                            ->orWhere('sender_id', Auth::id());
                    })
                        ->whereHas('contents', function ($query) {
                            $query->where('viewed', 0)->where('sender_id', '!=', Auth::id());
                        })
                        ->count();

                    $notificationsCount = Notification::where(['user_id' => Auth::id(), 'read' => 0])->count();
                    $notificationList = Notification::where(['user_id' => Auth::id()])->orderBy('created_at', 'desc')->take(3)->get();

                    $view->with('unreadMessageCount', $unreadMessageCount);
                    $view->with('notificationsCount', $notificationsCount);
                    $view->with('notificationList', $notificationList);
                }

                $view->with('recommended_users', $users);
                $view->with('popular_categories', $categories);
                $view->with('users_count', $usersCount);
                $view->with('all_categories', $all_categories);
            });
        }
    }

    protected function checkDatabaseConfiguration()
    {
        if (
            empty(config('database.connections.mysql.database')) ||
            empty(config('database.connections.mysql.username')) ||
            empty(config('database.connections.mysql.password'))
        ) {
            return false;
        }

        return true;
    }
}
