<!DOCTYPE html>
<html lang="{{ str_replace('_', '-', app()->getLocale()) }}" class="h-full">
<head>
	<meta charset="UTF-8" />
	{{-- <link rel="icon" type="image/svg+xml" href="/vite.svg" /> --}}
	<meta name="viewport" content="width=device-width, initial-scale=1.0" />
	<meta name="csrf-token" content="{{ csrf_token() }}">
    <title>@yield('title', $title ?? '') - {{ get_setting('site_title', 'typn') }}</title>

    <!-- Scripts -->
    @vite(['resources/css/app.css', 'resources/js/app.js'])

    <!-- Styles -->
    @livewireStyles

    <script>
        if (localStorage.getItem('dark-mode') === 'false' || !('dark-mode' in localStorage)) {
            document.querySelector('html').classList.remove('dark');
            document.querySelector('html').style.colorScheme = 'light';
        } else {
            document.querySelector('html').classList.add('dark');
            document.querySelector('html').style.colorScheme = 'dark';
        }
    </script>

    <link rel="preconnect" href="https://fonts.googleapis.com">
    <link rel="preconnect" href="https://fonts.gstatic.com" crossorigin>
    <link href="https://fonts.googleapis.com/css2?family=Inter:wght@100;200;300;400;500;600;700;800;900&display=swap" rel="stylesheet">

    <link rel="stylesheet" type="text/css" href="https://unpkg.com/trix@2.0.0/dist/trix.css">
    <script type="text/javascript" src="https://unpkg.com/trix@2.0.0/dist/trix.umd.min.js"></script>

    <script src="https://cdn.paddle.com/paddle/v2/paddle.js"></script>
</head>

<body class="font-inter antialiased bg-slate-100 dark:bg-slate-900 text-slate-600 dark:text-slate-400">

    <div class="flex h-[100dvh] overflow-hidden">
        <div class="relative flex flex-col flex-1 overflow-y-auto overflow-x-hidden">

            <!-- Site header -->
            <header class="sticky top-0 bg-white dark:bg-[#182235] border-b border-slate-200 dark:border-slate-700 z-30">
                <div class="px-4 sm:px-6 lg:px-8 py-8 md:py-0 w-full @if(!isset($wide)) max-w-9xl mx-auto @endisset">
                    <div class="flex items-center justify-between h-16 -mb-px">

                        <div>
                            <a wire:navigate href="{{route('home')}}" class="font-bold text-lg flex items-center gap-1">
                                <div class="w-7 h-7 bg-blue-700 hover:ring-2 hover:ring-inset hover:bg-transparent hover:ring-blue-700 hover:text-blue-700 text-white flex items-center justify-center rounded transition-all group">
                                    {{-- <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" class="w-4 h-4">
                                        <path fill-rule="evenodd" d="M9.315 7.584C12.195 3.883 16.695 1.5 21.75 1.5a.75.75 0 01.75.75c0 5.056-2.383 9.555-6.084 12.436A6.75 6.75 0 019.75 22.5a.75.75 0 01-.75-.75v-4.131A15.838 15.838 0 016.382 15H2.25a.75.75 0 01-.75-.75 6.75 6.75 0 017.815-6.666zM15 6.75a2.25 2.25 0 100 4.5 2.25 2.25 0 000-4.5z" clip-rule="evenodd" />
                                        <path d="M5.26 17.242a.75.75 0 10-.897-1.203 5.243 5.243 0 00-2.05 5.022.75.75 0 00.625.627 5.243 5.243 0 005.022-2.051.75.75 0 10-1.202-.897 3.744 3.744 0 01-3.008 1.51c0-1.23.592-2.323 1.51-3.008z" />
                                    </svg> --}}
                                    <svg xmlns="http://www.w3.org/2000/svg" class="w-5 h-5 stroke-white group-hover:stroke-black transition-all" viewBox="0 0 24 24" stroke-width="2" stroke="#2c3e50" fill="none" stroke-linecap="round" stroke-linejoin="round">
                                        <path stroke="none" d="M0 0h24v24H0z" fill="none"/>
                                        <path d="M5 7l5 5l-5 5" />
                                        <path d="M12 19l7 0" />
                                    </svg>
                                </div>
                                <span class="text-black dark:text-slate-200">{{ get_setting('site_title', 'typn') }}</span>
                            </a>
                        </div>

                        <!-- Header: Right side -->
                        <div class="flex items-center space-x-3">

                            <!-- Search button -->
                            <div x-data="{ searchOpen: false }">
                                <!-- Button -->
                                <button
                                    class="w-8 h-8 flex items-center justify-center bg-slate-100 hover:bg-slate-200 dark:bg-slate-700 dark:hover:bg-slate-600/80 rounded-full"
                                    :class="{ 'bg-slate-200': searchOpen }"
                                    @click.prevent="searchOpen = true;if (searchOpen) $nextTick(()=>{});"
                                    aria-controls="search-modal"
                                >
                                    <span class="sr-only">{{ __('Search') }}</span>
                                    <svg class="w-4 h-4" viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg">
                                        <path class="fill-current text-slate-500 dark:text-slate-400" d="M7 14c-3.86 0-7-3.14-7-7s3.14-7 7-7 7 3.14 7 7-3.14 7-7 7zM7 2C4.243 2 2 4.243 2 7s2.243 5 5 5 5-2.243 5-5-2.243-5-5-5z" />
                                        <path class="fill-current text-slate-400 dark:text-slate-500" d="M15.707 14.293L13.314 11.9a8.019 8.019 0 01-1.414 1.414l2.393 2.393a.997.997 0 001.414 0 .999.999 0 000-1.414z" />
                                    </svg>
                                </button>
                                <livewire:search />
                            </div>

                            @if(Auth::check())
                            <!-- Notifications button -->
                            <div class="relative inline-flex" x-data="{ open: false }">
                                <button
                                    class="w-8 h-8 flex items-center justify-center bg-slate-100 hover:bg-slate-200 dark:bg-slate-700 dark:hover:bg-slate-600/80 rounded-full"
                                    :class="{ 'bg-slate-200': open }"
                                    aria-haspopup="true"
                                    @click.prevent="open = !open"
                                    :aria-expanded="open"
                                >
                                    <span class="sr-only">{{ __('Notifications') }}</span>
                                    {{-- <svg class="w-4 h-4" viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg">
                                        <path class="fill-current text-slate-500 dark:text-slate-400" d="M6.5 0C2.91 0 0 2.462 0 5.5c0 1.075.37 2.074 1 2.922V12l2.699-1.542A7.454 7.454 0 006.5 11c3.59 0 6.5-2.462 6.5-5.5S10.09 0 6.5 0z" />
                                        <path class="fill-current text-slate-400 dark:text-slate-500" d="M16 9.5c0-.987-.429-1.897-1.147-2.639C14.124 10.348 10.66 13 6.5 13c-.103 0-.202-.018-.305-.021C7.231 13.617 8.556 14 10 14c.449 0 .886-.04 1.307-.11L15 16v-4h-.012C15.627 11.285 16 10.425 16 9.5z" />
                                    </svg> --}}

                                    <svg xmlns="http://www.w3.org/2000/svg" viewBox="0 0 24 24" fill="currentColor" class="w-4 h-4 text-slate-500 dark:text-slate-400">
                                        <path fill-rule="evenodd" d="M5.25 9a6.75 6.75 0 0113.5 0v.75c0 2.123.8 4.057 2.118 5.52a.75.75 0 01-.297 1.206c-1.544.57-3.16.99-4.831 1.243a3.75 3.75 0 11-7.48 0 24.585 24.585 0 01-4.831-1.244.75.75 0 01-.298-1.205A8.217 8.217 0 005.25 9.75V9zm4.502 8.9a2.25 2.25 0 104.496 0 25.057 25.057 0 01-4.496 0z" clip-rule="evenodd" />
                                      </svg>

                                    @if($notificationsCount > 0)
                                    <div class="absolute top-0 right-0 w-2.5 h-2.5 bg-rose-500 border-2 border-white dark:border-[#182235] rounded-full"></div>
                                    @endif
                                </button>
                                <div
                                    class="origin-top-right z-10 absolute top-full right-0 -mr-48 sm:mr-0 min-w-80 bg-white dark:bg-slate-800 border border-slate-200 dark:border-slate-700 pt-1.5 rounded shadow-lg overflow-hidden mt-1"
                                    @click.outside="open = false"
                                    @keydown.escape.window="open = false"
                                    x-show="open"
                                    x-transition:enter="transition ease-out duration-200 transform"
                                    x-transition:enter-start="opacity-0 -translate-y-2"
                                    x-transition:enter-end="opacity-100 translate-y-0"
                                    x-transition:leave="transition ease-out duration-200"
                                    x-transition:leave-start="opacity-100"
                                    x-transition:leave-end="opacity-0"
                                    x-cloak
                                >
                                    <div class="text-xs font-semibold text-slate-400 dark:text-slate-500 uppercase pt-1.5 pb-2 px-4">{{ __('Notifications') }}</div>
                                    <ul>
                                        @foreach($notificationList as $notification)
                                        <li class="border-b border-slate-200 dark:border-slate-700 last:border-0">
                                            <a
                                                class="block py-2 px-4 hover:bg-slate-50 dark:hover:bg-slate-700/20 @if(!$notification->read) bg-gray-100 dark:bg-slate-700 @endif"
                                                href="{{ $notification->type == "follow" ? route('user-profile', $notification->user->username) : route('thread', $notification->thread->slug ?? '') }}"
                                                @click="open = false" @focus="open = true" @focusout="open = false">
                                                <span class="block text-sm mb-2">
                                                    @if($notification->type == "thread_comment")
                                                        {!! __(":name commented on the topic :title", ['name' => $notification->user->name, 'title' => '<span class="font-bold">' . $notification->thread->title . '</span>']) !!}
                                                    @elseif($notification->type == "thread_like")
                                                        {!! __(":name upvoted for your thread :title", ['name' => $notification->user->name, 'title' => '<span class="font-bold">' . $notification->thread->title . '</span>']) !!}
                                                    @elseif($notification->type == "comment_like")
                                                        {!! __(":name upvoted your comment in the thread :title", ['name' => $notification->user->name, 'title' => '<span class="font-bold">' . $notification->thread->title . '</span>']) !!}
                                                    @elseif($notification->type == "reply_like")
                                                        {!! __(":name upvoted for your reply in the thread :title", ['name' => $notification->user->name, 'title' => '<span class="font-bold">' . $notification->thread->title . '</span>']) !!}
                                                    @elseif($notification->type == "comment_reply")
                                                        {!! __(":name replied to your comment in the thread :title", ['name' => $notification->user->name, 'title' => '<span class="font-bold">' . $notification->thread->title . '</span>']) !!}
                                                    @elseif($notification->type == "follow")
                                                        {!! __(':name started following you.', ['name' => $notification->user->name]) !!}
                                                    @endif
                                                </span>
                                                <span class="block text-xs font-medium text-slate-400 dark:text-slate-500">{{ $notification->created_at->translatedFormat('j F / H:m') }}</span>
                                            </a>
                                        </li>
                                        @endforeach
                                        <li>
                                            <a wire:navigate href="{{ route('notifications') }}" class="block py-2 px-4 hover:bg-slate-50 dark:hover:bg-slate-700/20 text-xs text-center">{{ __('View All') }}</a>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                            @endif

                            <!-- Dark mode toggle -->
                            <div>
                                <input type="checkbox" name="light-switch" id="light-switch" class="light-switch sr-only" />
                                <label class="flex items-center justify-center cursor-pointer w-8 h-8 bg-slate-100 hover:bg-slate-200 dark:bg-slate-700 dark:hover:bg-slate-600/80 rounded-full" for="light-switch">
                                    <svg class="w-4 h-4 dark:hidden" viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg">
                                        <path class="fill-current text-slate-400" d="M7 0h2v2H7V0Zm5.88 1.637 1.414 1.415-1.415 1.413-1.414-1.414 1.415-1.414ZM14 7h2v2h-2V7Zm-1.05 7.433-1.415-1.414 1.414-1.414 1.415 1.413-1.414 1.415ZM7 14h2v2H7v-2Zm-4.02.363L1.566 12.95l1.415-1.414 1.414 1.415-1.415 1.413ZM0 7h2v2H0V7Zm3.05-5.293L4.465 3.12 3.05 4.535 1.636 3.121 3.05 1.707Z" />
                                        <path class="fill-current text-slate-500" d="M8 4C5.8 4 4 5.8 4 8s1.8 4 4 4 4-1.8 4-4-1.8-4-4-4Z" />
                                    </svg>
                                    <svg class="w-4 h-4 hidden dark:block" viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg">
                                        <path class="fill-current text-slate-400" d="M6.2 2C3.2 2.8 1 5.6 1 8.9 1 12.8 4.2 16 8.1 16c3.3 0 6-2.2 6.9-5.2C9.7 12.2 4.8 7.3 6.2 2Z" />
                                        <path class="fill-current text-slate-500" d="M12.5 6a.625.625 0 0 1-.625-.625 1.252 1.252 0 0 0-1.25-1.25.625.625 0 1 1 0-1.25 1.252 1.252 0 0 0 1.25-1.25.625.625 0 1 1 1.25 0c.001.69.56 1.249 1.25 1.25a.625.625 0 1 1 0 1.25c-.69.001-1.249.56-1.25 1.25A.625.625 0 0 1 12.5 6Z" />
                                    </svg>
                                    <span class="sr-only">{{ __('Switch to light / dark version') }}</span>
                                </label>
                            </div>

                            <!-- Divider -->
                            <hr class="w-px h-6 bg-slate-200 dark:bg-slate-700 border-none" />

                            @if(Auth::check())
                            <!-- User button -->
                            <div class="relative inline-flex" x-data="{ open: false }">
                                <button
                                    class="inline-flex justify-center items-center group"
                                    aria-haspopup="true"
                                    @click.prevent="open = !open"
                                    :aria-expanded="open"
                                >
                                    <x-user.avatar :user="Auth::user()" />
                                    <div class="flex items-center truncate">
                                        <span class="truncate ml-2 text-sm font-medium dark:text-slate-300 group-hover:text-slate-800 dark:group-hover:text-slate-200">{{ Auth::user()->name }}</span>
                                        <svg class="w-3 h-3 shrink-0 ml-1 fill-current text-slate-400" viewBox="0 0 12 12">
                                            <path d="M5.9 11.4L.5 6l1.4-1.4 4 4 4-4L11.3 6z" />
                                        </svg>
                                    </div>
                                </button>
                                <div
                                    class="origin-top-right z-10 absolute top-full right-0 min-w-44 bg-white dark:bg-slate-800 border border-slate-200 dark:border-slate-700 py-1.5 rounded shadow-lg overflow-hidden mt-1"
                                    @click.outside="open = false"
                                    @keydown.escape.window="open = false"
                                    x-show="open"
                                    x-transition:enter="transition ease-out duration-200 transform"
                                    x-transition:enter-start="opacity-0 -translate-y-2"
                                    x-transition:enter-end="opacity-100 translate-y-0"
                                    x-transition:leave="transition ease-out duration-200"
                                    x-transition:leave-start="opacity-100"
                                    x-transition:leave-end="opacity-0"
                                    x-cloak
                                >
                                    <div class="pt-0.5 pb-2 px-3 mb-1 border-b border-slate-200 dark:border-slate-700">
                                        <div class="font-medium text-slate-800 dark:text-slate-100">{{ Auth::user()->name }}</div>
                                        <div class="text-xs text-slate-500 dark:text-slate-400 italic">{{ '@' . Auth::user()->username }}</div>
                                    </div>
                                    <ul>
                                        <li>
                                            <a
                                                wire:navigate
                                                class="font-medium text-sm text-indigo-500 hover:text-indigo-600 dark:hover:text-indigo-400 flex items-center py-1 px-3"
                                                href="{{ route('user-profile', Auth::user()->username) }}" @click="open = false" @focus="open = true" @focusout="open = false">
                                                {{ __('Profile') }}
                                            </a>
                                        </li>
                                        <li>
                                            <a
                                                wire:navigate
                                                class="font-medium text-sm text-indigo-500 hover:text-indigo-600 dark:hover:text-indigo-400 flex items-center py-1 px-3"
                                                href="{{ route('edit-profile.index') }}" @click="open = false" @focus="open = true" @focusout="open = false">
                                                {{ __('Account Settings') }}
                                            </a>
                                        </li>
                                        {{-- <li>
                                            <a
                                                wire:navigate
                                                class="font-medium text-sm text-indigo-500 hover:text-indigo-600 dark:hover:text-indigo-400 flex items-center py-1 px-3"
                                                href="{{ route('edit-profile.premium') }}" @click="open = false" @focus="open = true" @focusout="open = false">
                                                {{ __('Premium') }}
                                            </a>
                                        </li> --}}
                                        <li>
                                            <a
                                                wire:navigate
                                                class="font-medium text-sm text-indigo-500 hover:text-indigo-600 dark:hover:text-indigo-400 flex items-center py-1 px-3"
                                                href="{{ route('logout') }}" @click="open = false" @focus="open = true" @focusout="open = false">
                                                {{ __('Logout') }}
                                            </a>
                                        </li>
                                    </ul>
                                </div>
                            </div>
                            @else
                                <div class="flex items-center gap-2">
                                    <a
                                        wire:navigate
                                        class="text-sm rounded-full py-1.5 px-4 transition-all"
                                        href="{{ route('login') }}">
                                        {{ __('Log in') }}
                                    </a>
                                    <a
                                        wire:navigate
                                        class="text-sm bg-slate-100 hover:bg-slate-200 dark:bg-slate-700 dark:hover:bg-slate-600/80 rounded-full py-1.5 px-4 transition-all"
                                        href="{{ route('register') }}">
                                        {{ __('Create account') }}
                                    </a>
                                </div>
                            @endif
                        </div>

                    </div>
                </div>
            </header>

            <main class="grow">
                <div class="@if(!isset($wide)) px-4 sm:px-6 lg:px-8 py-8 md:py-0 w-full max-w-9xl mx-auto @else h-full @endif">

                    @yield('content')
                    {{$slot ?? ''}}

                </div>
            </main>

        </div>
    </div>

    <livewire:modals.login />

    @livewireScripts

    <script>
        // Light switcher
        var lightSwitches = document.querySelectorAll('.light-switch');
        if (lightSwitches.length > 0) {
        lightSwitches.forEach((lightSwitch, i) => {
            if (localStorage.getItem('dark-mode') === 'true') {
            // eslint-disable-next-line no-param-reassign
            lightSwitch.checked = true;
            }
            lightSwitch.addEventListener('change', () => {
            var { checked } = lightSwitch;
            lightSwitches.forEach((el, n) => {
                if (n !== i) {
                // eslint-disable-next-line no-param-reassign
                el.checked = checked;
                }
            });
            document.documentElement.classList.add('[&_*]:!transition-none');
            if (lightSwitch.checked) {
                document.documentElement.classList.add('dark');
                document.querySelector('html').style.colorScheme = 'dark';
                localStorage.setItem('dark-mode', true);
                document.dispatchEvent(new CustomEvent('darkMode', { detail: { mode: 'on' } }));
            } else {
                document.documentElement.classList.remove('dark');
                document.querySelector('html').style.colorScheme = 'light';
                localStorage.setItem('dark-mode', false);
                document.dispatchEvent(new CustomEvent('darkMode', { detail: { mode: 'off' } }));
            }
            setTimeout(() => {
                document.documentElement.classList.remove('[&_*]:!transition-none');
            }, 1);
            });
        });
        }

        // document.querySelectorAll('.reply-button').forEach(item => {
        //     item.addEventListener('click', (e) => {

        //         document.querySelectorAll('.comment-reply').forEach(reply => {
        //             reply.classList.add('hidden')
        //         })

        //         e.target.closest('.comment').querySelector('.comment-reply').classList.toggle('hidden')
        //         e.target.closest('.comment').querySelector('.comment-reply textarea').value = ""
        //     })
        // })

        Livewire.on('not-login', () => {
            document.querySelector('#login-modal').classList.remove('hidden')
        })

        Livewire.on('login-refresh', () => {
            document.querySelector('#login-modal').classList.add('hidden')
            location.reload()
        })

        document.querySelector('#login-modal .close-button').addEventListener('click', () => {
            document.querySelector('#login-modal').classList.add('hidden')
        })

        document.querySelectorAll('.not-login').forEach(item => {
            item.addEventListener('click', () => {
                Livewire.dispatch('not-login')
                return false
            })
        })

        Livewire.on('refreshPage', () => {
            location.reload();
        })

        // function addReplyButtonListeners() {
        //     document.querySelectorAll('.reply-button').forEach(item => {
        //         item.addEventListener('click', (e) => {
        //             document.querySelectorAll('.comment-reply').forEach(reply => {
        //                 reply.classList.add('hidden')
        //             });

        //             e.target.closest('.comment').querySelector('.comment-reply').classList.toggle('hidden');
        //             e.target.closest('.comment').querySelector('.comment-reply textarea').value = "";
        //         });
        //     });
        // }

        // addReplyButtonListeners()
    </script>
</body>
</html>
