<div class="my-8">

    <x-parts.admin.navigation />

    <div class="bg-white dark:bg-slate-800 shadow-lg rounded-sm mb-8">
        <div class="flex flex-col md:flex-row md:-mr-px">

            <!-- Panel -->
            <div class="grow">

                <!-- Panel body -->
                <div class="p-6 space-y-6">
                    <h2 class="text-2xl text-slate-800 dark:text-slate-100 font-bold mb-5">{{ __('My Account') }}</h2>

                    @if (session('success'))
                        <div class="p-4 mb-4 text-sm text-green-800 rounded-lg bg-green-50 dark:bg-gray-800 dark:text-green-400" role="alert">
                            {{ session('success') }}
                        </div>
                    @elseif (session('error'))
                        <div class="p-4 mb-4 text-sm text-red-800 rounded-lg bg-red-50 dark:bg-gray-800 dark:text-red-400" role="alert">
                            {{ session('error') }}
                        </div>
                    @endif

                    <form class="flex items-center gap-5" wire:submit="uploadAvatar">
                        @if($user->profile_photo_path)
                            @if($avatar)
                                <img class="w-20 h-20 rounded-full object-cover" src="{{ $avatar->temporaryUrl() }}">
                            @else
                                <img class="w-20 h-20 rounded-full object-cover" src="{{ $user->profile_photo_path }}">
                            @endif
                        @elseif ($avatar)
                            <img class="w-20 h-20 rounded-full object-cover" src="{{ $avatar->temporaryUrl() }}">
                        @else
                            <div class="w-20 h-20 bg-gray-100 dark:bg-slate-900 rounded-full flex items-center justify-center text-2xl dark:text-slate-200 font-bold text-gray-400 uppercase">
                                {{mb_substr($user->username, 0, 1)}}
                            </div>
                        @endif

                        <div class="flex items-center gap-2">
                            <label class="text-white bg-indigo-500 hover:bg-indigo-600 font-medium rounded-md text-sm px-3 py-1.5 inline-flex items-center gap-1 transition-all cursor-pointer">
                                <input id="avatar" type="file" wire:model="avatar" class="hidden">
                                <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-4 h-4">
                                    <path stroke-linecap="round" stroke-linejoin="round" d="M3 16.5v2.25A2.25 2.25 0 005.25 21h13.5A2.25 2.25 0 0021 18.75V16.5m-13.5-9L12 3m0 0l4.5 4.5M12 3v13.5" />
                                </svg>
                                {{ __('Change') }}
                            </label>
                            @if($avatar)
                                <button class="text-gray-900 ring-1 ring-gray-200 bg-white dark:bg-slate-700 dark:ring-slate-600 dark:text-slate-100 focus:outline-none hover:bg-gray-100 font-medium rounded-md text-sm px-3 py-1.5 transition-all" type="submit">
                                    {{ __('Upload') }}
                                </button>
                            @endif
                        </div>
                    </form>

                    <form wire:submit="general">

                    <section>
                        <h3 class="text-xl leading-snug text-slate-800 dark:text-slate-100 font-bold mb-1">{{ __('General Details') }}</h3>
                        <div class="text-sm">{{ __('You can edit general information about your account from this area.') }}</div>
                        <div class="grid grid-cols-3 gap-4 mt-5">
                            <div>
                                <label class="block text-sm font-medium mb-1" for="name">{{ __('Full Name') }}</label>
                                <input wire:model="name" id="name" class="form-input w-full" type="text"  />
                                @error('name') <div class="text-red-500 mt-1 text-xs font-medium">{{ $message }}</div> @enderror
                            </div>
                            <div>
                                <label class="block text-sm font-medium mb-1" for="username">{{ __('Username') }}</label>
                                <input wire:model="username" id="username" class="form-input w-full" type="text" />
                                @error('username') <div class="text-red-500 mt-1 text-xs font-medium">{{ $message }}</div> @enderror
                            </div>
                            <div>
                                <label class="block text-sm font-medium mb-1" for="website">{{ __('Website') }}</label>
                                <input wire:model="website" id="website" class="form-input w-full" type="text" />
                                @error('website') <div class="text-red-500 mt-1 text-xs font-medium">{{ $message }}</div> @enderror
                            </div>
                            <div>
                                <label class="block text-sm font-medium mb-1" for="location">{{ __('Location') }}</label>
                                <input wire:model="location" id="location" class="form-input w-full" type="text" />
                            </div>
                            <div>
                                <label class="block text-sm font-medium mb-1" for="job">{{ __('Job') }}</label>
                                <input wire:model="job" id="job" class="form-input w-full" type="text" />
                            </div>
                            <div>
                                <label class="block text-sm font-medium mb-1" for="job">{{ __('About') }}</label>
                                <input wire:model="about" id="job" class="form-input w-full" type="text" />
                            </div>
                            <div>
                                <label class="block text-sm font-medium mb-1" for="email">{{ __('Email') }}</label>
                                <input wire:model="email" id="email" class="form-input w-full" type="text" />
                                @error('email') <div class="text-red-500 mt-1 text-xs font-medium">{{ $message }}</div> @enderror
                            </div>
                        </div>
                    </section>
                </div>

                    <!-- Panel footer -->
                    <footer>
                        <div class="flex flex-col px-6 py-5 border-t border-slate-200 dark:border-slate-700">
                            <div class="flex self-end">
                                <button type="submit" class="btn bg-indigo-500 hover:bg-indigo-600 text-white ml-3">{{ __('Save Changes') }}</button>
                            </div>
                        </div>
                    </footer>
                </form>
            </div>

        </div>
    </div>
</div>
