<div class="my-8">

    <x-parts.admin.navigation />

    <div class="mb-8 flex items-center justify-between">
        <h1 class="text-2xl md:text-3xl text-slate-800 dark:text-slate-100 font-bold">
            {{ __('Categories') }}
        </h1>

        <div>
            <button wire:click="toggle" class="btn bg-indigo-500 hover:bg-indigo-600 text-white">
                {{ __('Add New') }}
            </button>
        </div>        
    </div>

    @if (session('success'))
        <div class="p-4 mb-4 text-sm text-green-800 rounded-lg bg-green-50 dark:bg-gray-800 dark:text-green-400" role="alert">
            {{ session('success') }}
        </div>
    @elseif (session('error'))
        <div class="p-4 mb-4 text-sm text-red-800 rounded-lg bg-red-50 dark:bg-gray-800 dark:text-red-400" role="alert">
            {{ session('error') }}
        </div>
    @endif

    @if($activeToggle)
        <div class="border-t border-slate-200 dark:border-slate-700 py-5 bg-white dark:bg-slate-700 p-5 mb-5">
            <form wire:submit="add" class="space-y-5">

                <div>
                    <label class="block text-sm font-medium mb-1" for="title">{{ __('Title') }}</label>
                    <input wire:model="title" id="title" class="form-input w-full" type="text">
                    @error('title') <div class="text-xs mt-1 text-rose-500">{{ $message }}</div> @enderror
                </div>

                <div>
                    <label class="block text-sm font-medium mb-1" for="title">{{ __('Content') }}</label>
                    <input wire:model="description" id="description" type="hidden" name="description">
                    <div wire:ignore>
                        <trix-editor
                        class="trix-editor"
                        wire:ignore
                        wire:trix-change="setContent($event.target.value)"
                        input="description"
                        ></trix-editor>
                    </div>
                    @error('description') <div class="text-xs mt-1 text-rose-500">{{ $message }}</div> @enderror
                </div>
                <button type="submit" class="inline-flex items-center px-5 py-2.5 mt-4 sm:mt-6 text-sm font-medium text-center text-white bg-blue-500 rounded-lg focus:ring-4 focus:ring-primary-200 dark:focus:ring-primary-900 hover:bg-primary-800">
                    {{ __('Create') }}
                </button>
            </form>
        </div>
    @endif    

    <div class="bg-white dark:bg-slate-800 shadow-lg rounded-sm border border-slate-200 dark:border-slate-700">
        <header class="px-5 py-4">
            <h2 class="font-semibold text-slate-800 dark:text-slate-100">{{ __('All Categories') }}
                <span class="text-slate-400 dark:text-slate-500 font-medium">{{ $categoryCount }}</span>
            </h2>
        </header>
        <div>

            <!-- Table -->
            <div class="overflow-x-auto md:overflow-visible">
                <table class="table-auto w-full dark:text-slate-300">
                    <!-- Table header -->
                    <thead class="text-xs font-semibold uppercase text-slate-500 dark:text-slate-400 bg-slate-50 dark:bg-slate-900/20 border-t border-b border-slate-200 dark:border-slate-700">
                        <tr>
                            <th class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <div class="font-semibold text-left">{{ __('Name') }}</div>
                            </th>
                            <th class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <div class="font-semibold text-left">{{ __('Slug') }}</div>
                            </th>
                            <th class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <div class="font-semibold text-left">{{ __('Jobs') }}</div>
                            </th>
                            <th class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <span class="sr-only">{{ __('Menu') }}</span>
                            </th>
                        </tr>
                    </thead>
                    <!-- Table body -->
                    <tbody class="text-sm divide-y divide-slate-200 dark:divide-slate-700">
                        @foreach($categories as $category)
                        <tr>
                            <td class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <div class="flex items-center">
                                    <div class="font-bold text-slate-800 dark:text-slate-100">
                                        {{ $category->title }}
                                    </div>
                                </div>
                            </td>
                            <td class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <div class="text-left">{{ $category->slug }}</div>
                            </td>
                            <td class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap">
                                <div class="text-left">{{ $category->jobs->count() }}</div>
                            </td>
                            <td class="px-2 first:pl-5 last:pr-5 py-3 whitespace-nowrap w-px">
                                <div class="relative inline-flex" x-data="{ open: false }">
                                    <button class="rounded-full text-slate-400 hover:text-slate-500 dark:text-slate-500 dark:hover:text-slate-400" :class="open ? 'bg-slate-100 dark:bg-slate-700 text-slate-500 dark:text-slate-400': 'text-slate-400 hover:text-slate-500 dark:text-slate-500 dark:hover:text-slate-400'" aria-haspopup="true" @click.prevent="open = !open" :aria-expanded="open" aria-expanded="false">
                                        <span class="sr-only">Menu</span>
                                        <svg class="w-8 h-8 fill-current" viewBox="0 0 32 32">
                                            <circle cx="16" cy="16" r="2"></circle>
                                            <circle cx="10" cy="16" r="2"></circle>
                                            <circle cx="22" cy="16" r="2"></circle>
                                        </svg>
                                    </button>
                                    <div class="origin-top-right z-10 absolute top-full right-0 min-w-36 bg-white dark:bg-slate-800 border border-slate-200 dark:border-slate-700 py-1.5 rounded shadow-lg overflow-hidden mt-1" @click.outside="open = false" @keydown.escape.window="open = false" x-show="open" x-transition:enter="transition ease-out duration-200 transform" x-transition:enter-start="opacity-0 -translate-y-2" x-transition:enter-end="opacity-100 translate-y-0" x-transition:leave="transition ease-out duration-200" x-transition:leave-start="opacity-100" x-transition:leave-end="opacity-0" style="display: none;">
                                        <ul>
                                            <li>
                                                <a
                                                    wire:navigate
                                                    class="font-medium text-sm text-slate-600 dark:text-slate-300 hover:text-slate-800 dark:hover:text-slate-200 flex py-1 px-3"
                                                    href="{{ route('dashboard.edit-job-category', $category->id) }}"
                                                    @click="open = false" @focus="open = true" @focusout="open = false">
                                                    {{ __('Edit') }}
                                                </a>
                                            </li>
                                            <li>
                                                <button wire:click="delete({{$category->id}})" class="font-medium text-sm text-rose-500 hover:text-rose-600 flex py-1 px-3" href="#0" @click="open = false" @focus="open = true" @focusout="open = false">
                                                    {{ __('Delete') }}
                                                </button>
                                            </li>
                                        </ul>
                                    </div>
                                </div>
                            </td>
                        </tr>
                        @endforeach
                    </tbody>
                </table>
            </div>
        </div>
    </div>

    <div class="mt-5">{{$categories->links()}}</div>

    <script>
        function keepModalOpen(event) {
            event.stopPropagation();
        }
    </script>
</div>
