<div class="xl:flex">

    <script src="https://cdn.quilljs.com/1.3.6/quill.min.js"></script>
    <link href="https://cdn.quilljs.com/1.3.6/quill.snow.css" rel="stylesheet">

    <div class="md:flex flex-1">
        <x-parts.left-sidebar />
        <div class="flex-1 md:ml-8 xl:mx-4 2xl:mx-8">
            <div class="md:py-8">

                <form
                wire:submit="create"
                class="space-y-3  bg-white dark:bg-slate-800 border-slate-200 dark:border-slate-700  shadow-lg rounded-sm border  px-5 py-4">
                <div>
                    <label class="block text-sm font-medium mb-1" for="normal">{{ __('Job Title') }}</label>
                    <input wire:model="title" id="normal" class="form-input w-full" type="text">
                    <div class="text-xs mt-1">{{ __('Enter a short descriptive title.') }}</div>
                    @error('title') <div class="text-xs mt-1 text-rose-500">{{ $message }}</div> @enderror
                </div>
                
                <div wire:ignore>
                    <label class="block text-sm font-medium mb-1" for="normal">{{ __('Details') }}</label>
                    <input id="content" type="hidden" name="content" value="{{$content}}">
                    <trix-editor
                    id="trix"
                    trix-focus="false"
                    trix-blur="false"
                    wire:ignore
                    {{-- class="trix-editor"
                    wire:ignore --}}
                    {{-- wire:trix-change="setJobContent($event.target.value)" --}}
                    input="content"
                    ></trix-editor>
                    @error('content') <div class="text-xs mt-1 text-rose-500">{{ $message }}</div> @enderror
                </div>
                <div class="grid grid-cols-2 gap-5">
                    <div>
                        <label class="block text-sm font-medium mb-1" for="prefix">{{ __('Budget') }}</label>
                        <div class="relative">
                            <input wire:model="budget" id="prefix" class="form-input w-full !pl-12" type="text">
                            <div class="absolute inset-0 right-auto flex items-center pointer-events-none">
                                <span class="text-sm text-slate-400 dark:text-slate-500 font-medium px-3">{{ __('USD') }}</span>
                            </div>
                        </div>
                        @error('budget') <div class="text-xs mt-1 text-rose-500">{{ $message }}</div> @enderror
                    </div>
                    <div>
                        <label class="block text-sm font-medium mb-1" for="category">{{ __('Category') }}</label>
                        <select wire:model="category" id="category" class="form-select w-full">
                            <option>{{ __('Please Select') }}</option>
                            @foreach($job_categories as $category)
                            <option value="{{$category->id}}">{{ $category->title }}</option>
                            @endforeach
                        </select>
                        @error('category') <div class="text-xs mt-1 text-rose-500">{{ $message }}</div> @enderror
                    </div>
                </div>
                <div>
                    <button type="submit" class="btn bg-indigo-500 hover:bg-indigo-600 text-white">
                        <svg class="w-3 h-3 fill-current opacity-50 shrink-0" viewBox="0 0 16 16">
                            <path d="M15 7H9V1c0-.6-.4-1-1-1S7 .4 7 1v6H1c-.6 0-1 .4-1 1s.4 1 1 1h6v6c0 .6.4 1 1 1s1-.4 1-1V9h6c.6 0 1-.4 1-1s-.4-1-1-1z"></path>
                        </svg>
                        <span class="ml-2">{{ __('Create') }}</span>
                    </button>
                </div>
            </form>

            </div>
        </div>
    </div>

    <x-parts.right-sidebar />

    <script>
        (function() {
            var HOST = "{{ env('APP_URL') }}/upload";

            addEventListener("trix-attachment-add", function(event) {
                if(event.attachment.file.size > (1024 * 1024)){
                    event.preventDefault();
                }else{
                    if(
                    event.attachment.file.type == 'image/png' ||
                    event.attachment.file.type == 'image/jpg' ||
                    event.attachment.file.type == 'image/jpeg'
                ){
                    uploadFileAttachment(event.attachment)
                }
                }
            })

            function uploadFileAttachment(attachment) {
                uploadFile(attachment.file, setProgress, setAttributes)

                function setProgress(progress) {
                    attachment.setUploadProgress(progress)
                }

                function setAttributes(attributes) {
                    attachment.setAttributes(attributes)
                }
            }

            function uploadFile(file, progressCallback, successCallback) {
                var formData = createFormData(file);
                var xhr = new XMLHttpRequest();

                xhr.open("POST", HOST, true);
                xhr.setRequestHeader( 'X-CSRF-TOKEN', getMeta( 'csrf-token' ) );

                xhr.upload.addEventListener("progress", function(event) {
                    var progress = event.loaded / event.total * 100
                    progressCallback(progress)
                })

                xhr.addEventListener("load", function(event) {
                    var attributes = {
                        url: xhr.responseText,
                        href: xhr.responseText + "?content-disposition=attachment"
                    }
                    successCallback(attributes)
                })

                xhr.send(formData)
            }

            function createFormData(file) {
                var data = new FormData()
                data.append("Content-Type", file.type)
                data.append("file", file)
                return data
            }

            function getMeta(metaName) {
                const metas = document.getElementsByTagName('meta');

                for (let i = 0; i < metas.length; i++) {
                if (metas[i].getAttribute('name') === metaName) {
                    return metas[i].getAttribute('content');
                }
                }

                return '';
            }
        })();
    </script> 

    <script>
        var myToolbar= [
            ['bold', 'italic', 'underline', 'strike'],       
            ['blockquote', 'code-block'],

            //[{ 'color': [] }, { 'background': [] }],         
            //[{ 'font': [] }],
            [{ 'align': [] }],

            ['clean'],                                        
            ['image'] 
        ];

        var container = document.getElementById('editor-container');

        var quill = new Quill(container, {
            theme: 'snow',
            modules: {
                toolbar: {
                    container: myToolbar,
                    handlers: {
                        image: imageHandler
                    }
                }
            },
        });  

        function imageHandler() {
            var range = this.quill.getSelection();
            var value = prompt('Image URL:');
            if(value){
                this.quill.insertEmbed(range.index, 'image', value, Quill.sources.USER);
            }
        }    

        /*
        document.querySelector('.click').addEventListener('click', () => {
            const text = document.querySelector('.ql-editor').innerHTML

        })
        */
    </script>    
</div>
