<div>

    <div
        class="fixed inset-0 bg-slate-900 bg-opacity-30 z-50 transition-opacity"
        x-show="searchOpen"
        x-transition:enter="transition ease-out duration-200"
        x-transition:enter-start="opacity-0"
        x-transition:enter-end="opacity-100"
        x-transition:leave="transition ease-out duration-100"
        x-transition:leave-start="opacity-100"
        x-transition:leave-end="opacity-0"
        aria-hidden="true"
        x-cloak
    ></div>

    <div
        id="search-modal"
        class="fixed inset-0 z-50 overflow-hidden flex items-start top-20 mb-4 justify-center px-4 sm:px-6"
        role="dialog"
        aria-modal="true"
        x-show="searchOpen"
        x-transition:enter="transition ease-in-out duration-200"
        x-transition:enter-start="opacity-0 translate-y-4"
        x-transition:enter-end="opacity-100 translate-y-0"
        x-transition:leave="transition ease-in-out duration-200"
        x-transition:leave-start="opacity-100 translate-y-0"
        x-transition:leave-end="opacity-0 translate-y-4"
        x-cloak
    >
        <div
            class="bg-white dark:bg-slate-800 border border-transparent dark:border-slate-700 overflow-auto max-w-2xl w-full max-h-full rounded shadow-lg"
            @click.outside="searchOpen = false"
            @keydown.escape.window="searchOpen = false"
        >
            <!-- Search form -->
            <div class=" @if($search) border-b border-slate-200 dark:border-slate-700 @endif">
                <div class="relative">
                    <label for="modal-search" class="sr-only">{{ __('Search') }}</label>
                    <input
                        wire:model.live="search"
                        id="modal-search"
                        class="w-full dark:text-slate-300 bg-white dark:bg-slate-800 border-0 focus:ring-transparent placeholder-slate-400 dark:placeholder-slate-500 appearance-none py-3 pl-10 pr-4"
                        type="search"
                        placeholder="{{ __('Search for threads or job postings...') }}" x-ref="searchInput" />
                    <div class="absolute inset-0 right-auto group h-full flex items-center justify-center" type="submit" aria-label="Search">
                        <svg class="w-4 h-4 shrink-0 fill-current text-slate-400 dark:text-slate-500 group-hover:text-slate-500 dark:group-hover:text-slate-400 ml-4 mr-2" viewBox="0 0 16 16" xmlns="http://www.w3.org/2000/svg">
                            <path d="M7 14c-3.86 0-7-3.14-7-7s3.14-7 7-7 7 3.14 7 7-3.14 7-7 7zM7 2C4.243 2 2 4.243 2 7s2.243 5 5 5 5-2.243 5-5-2.243-5-5-5z" />
                            <path d="M15.707 14.293L13.314 11.9a8.019 8.019 0 01-1.414 1.414l2.393 2.393a.997.997 0 001.414 0 .999.999 0 000-1.414z" />
                        </svg>
                    </div>
                </div>
            </div>
            @if($search)
            <div class="py-4 px-2">
                @if($threads->count() < 1 && $jobs->count() < 1 && $users->count() < 1)
                    <p class="text-sm text-center">{{ __('No content matching your search was found.') }}</p>
                @else
                    @if($threads->count() > 0)
                    <div class="mb-3 last:mb-0">
                        <div class="text-xs font-semibold text-slate-400 dark:text-slate-500 uppercase px-2 mb-2">{{ __('Threads') }}</div>
                        <ul class="text-sm">
                            @foreach($threads as $thread)
                            <li>
                                <a
                                    wire:navigate
                                    class="flex items-center p-2 text-slate-800 dark:text-slate-100 hover:text-white hover:bg-indigo-500 rounded group"
                                    href="{{ route('thread', $thread->slug) }}"
                                    @click="searchOpen = false" @focus="searchOpen = true" @focusout="searchOpen = false">
                                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-4 h-4 text-slate-400 dark:text-slate-500 group-hover:text-white group-hover:text-opacity-50 shrink-0 mr-3">
                                        <path stroke-linecap="round" stroke-linejoin="round" d="M8.25 4.5l7.5 7.5-7.5 7.5" />
                                    </svg>
                                    <span>{{ $thread->title }}</span>
                                </a>
                            </li>
                            @endforeach
                        </ul>
                    </div>
                    @endif

                    @if($jobs->count() > 0)
                    <div class="mb-3 last:mb-0">
                        <div class="text-xs font-semibold text-slate-400 dark:text-slate-500 uppercase px-2 mb-2">{{ __('Jobs') }}</div>
                        <ul class="text-sm">
                            @foreach($jobs as $job)
                            <li>
                                <a
                                    wire:navigate
                                    class="flex items-center p-2 text-slate-800 dark:text-slate-100 hover:text-white hover:bg-indigo-500 rounded group"
                                    href="{{ route('jobs.single', $job->slug) }}"
                                    @click="searchOpen = false" @focus="searchOpen = true" @focusout="searchOpen = false">
                                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-4 h-4 text-slate-400 dark:text-slate-500 group-hover:text-white group-hover:text-opacity-50 shrink-0 mr-3">
                                        <path stroke-linecap="round" stroke-linejoin="round" d="M8.25 4.5l7.5 7.5-7.5 7.5" />
                                    </svg>
                                    <span>{{ $job->title }}</span>
                                </a>
                            </li>
                            @endforeach
                        </ul>
                    </div>
                    @endif

                    @if($users->count() > 0)
                    <div class="mb-3 last:mb-0">
                        <div class="text-xs font-semibold text-slate-400 dark:text-slate-500 uppercase px-2 mb-2">{{ __('Users') }}</div>
                        <ul class="text-sm">
                            @foreach($users as $user)
                            <li>
                                <a
                                    wire:navigate
                                    class="flex items-center p-2 text-slate-800 dark:text-slate-100 hover:text-white hover:bg-indigo-500 rounded group"
                                    href="{{ route('user-profile', $user->username) }}"
                                    @click="searchOpen = false" @focus="searchOpen = true" @focusout="searchOpen = false">
                                    <svg xmlns="http://www.w3.org/2000/svg" fill="none" viewBox="0 0 24 24" stroke-width="1.5" stroke="currentColor" class="w-4 h-4 text-slate-400 dark:text-slate-500 group-hover:text-white group-hover:text-opacity-50 shrink-0 mr-3">
                                        <path stroke-linecap="round" stroke-linejoin="round" d="M8.25 4.5l7.5 7.5-7.5 7.5" />
                                    </svg>
                                    <span>{{ $user->name }}</span>
                                </a>
                            </li>
                            @endforeach
                        </ul>
                    </div>
                    @endif
                @endif
            </div>
            @endif
        </div>
    </div>
</div>
