@extends('layouts.main')
@section('title', $thread->title)

@section('content')
    <div class="xl:flex">
        <div class="md:flex flex-1">
            <x-parts.left-sidebar />

            <div class="flex-1 md:ml-8 xl:mx-4 2xl:mx-8">
                <div class="md:py-8">
                    <article class="bg-white dark:bg-slate-800 shadow-md rounded border border-slate-200 dark:border-slate-700 p-5">

                        <!-- Breadcrumbs -->
                        <div class="mb-2">
                            <ul class="inline-flex flex-wrap text-sm font-medium">
                                <li class="flex items-center">
                                    <a
                                        wire:navigate
                                        class="text-slate-500 dark:text-slate-400 hover:text-indigo-500 dark:hover:text-indigo-500"
                                        href="{{route('home')}}">
                                        {{__('Home')}}
                                    </a>
                                    <svg class="h-4 w-4 fill-current text-slate-400 dark:text-slate-500 mx-2" viewBox="0 0 16 16">
                                        <path d="M6.6 13.4L5.2 12l4-4-4-4 1.4-1.4L12 8z" />
                                    </svg>
                                </li>
                                <li class="flex items-center">
                                    <a
                                        wire:navigate
                                        class="text-slate-500 dark:text-slate-400 hover:text-indigo-500 dark:hover:text-indigo-500"
                                        href="{{route('category', $thread->category->slug)}}">
                                        {{$thread->category->title}}
                                    </a>
                                </li>
                            </ul>
                        </div>

                        <!-- Header -->
                        <header class="pb-4">
                            <!-- Title -->
                            <div class="flex items-start space-x-3 mb-3">
                                <h2 class="text-2xl text-slate-800 dark:text-slate-100 font-bold flex-1">
                                    {{$thread->title}}
                                </h2>

                                <livewire:thread.item.upvote :id="$thread->id" />
                            </div>
                            <!-- Meta -->
                            <div class="flex flex-wrap text-sm">
                                <div class="flex items-center after:block after:content-['·'] last:after:content-[''] after:text-sm after:text-slate-400 dark:after:text-slate-600 after:px-2">
                                    <a
                                        href="{{ route('user-profile', $thread->user->username) }}"
                                        class="font-medium text-indigo-500 hover:text-indigo-600 dark:hover:text-indigo-400 flex items-center"
                                        wire:navigate
                                        >
                                        @if($thread->fixed)
                                        <svg class="w-4 h-4 mr-2 fill-current" xmlns="http://www.w3.org/2000/svg">
                                            <path d="M15.686 5.708 10.291.313c-.4-.4-.999-.4-1.399 0s-.4 1 0 1.399l.6.6-6.794 3.696-1-1C1.299 4.61.7 4.61.3 5.009c-.4.4-.4 1 0 1.4l1.498 1.498 2.398 2.398L.6 14.001 2 15.4l3.696-3.697L9.692 15.7c.5.5 1.199.2 1.398 0 .4-.4.4-1 0-1.4l-.999-.998 3.697-6.695.6.6c.599.6 1.199.2 1.398 0 .3-.4.3-1.1-.1-1.499Zm-7.193 6.095L4.196 7.507l6.695-3.697 1.298 1.299-3.696 6.694Z" />
                                        </svg>
                                        @endif
                                        {{ $thread->user->name }}
                                    </a>
                                </div>
                                <div class="flex items-center after:block after:content-['·'] last:after:content-[''] after:text-sm after:text-slate-400 dark:after:text-slate-600 after:px-2">
                                    <span class="text-slate-500">{{ $thread->created_at->diffForHumans() }}</span>
                                </div>
                                <div class="flex items-center after:block after:content-['·'] last:after:content-[''] after:text-sm after:text-slate-400 dark:after:text-slate-600 after:px-2">
                                    <span class="text-slate-500">{{ $thread->comments->count() > 0 ? $thread->comments->count() . __('Comments') : __('No Comment') }}</span>
                                </div>
                            </div>
                        </header>

                        <!-- Content -->
                        <div class="space-y-4 mb-6">
                            {{$thread->content}}
                        </div>

                        <livewire:thread.comments :id="$thread->id" />
                    </article>
                </div>
            </div>
        </div>

        <x-parts.right-sidebar :user="$thread->user" />
    </div>
@endsection
