<?php

use App\Http\Controllers\CategoryController;
use Illuminate\Support\Facades\Route;
use App\Http\Controllers\ThreadController;
use App\Http\Controllers\TrixController;
use App\Http\Middleware\AuthCheck;
use App\Http\Middleware\isAdmin;
use App\Http\Middleware\PremiumIsValid;
use App\Livewire\Category\Threads;
use App\Livewire\Changelogs;
use App\Livewire\Dashboard\Abuse;
use App\Livewire\Dashboard\Ad;
use App\Livewire\Dashboard\Category;
use App\Livewire\Dashboard\Comments;
use App\Livewire\Dashboard\EditCategory;
use App\Livewire\Dashboard\EditJobCategory;
use App\Livewire\Dashboard\EditUser;
use App\Livewire\Dashboard\Feedback as DashboardFeedback;
use App\Livewire\Dashboard\Index as DashboardIndex;
use App\Livewire\Dashboard\JobCategory;
use App\Livewire\Dashboard\Settings;
use App\Livewire\Dashboard\Users;
use App\Livewire\Favorites;
use App\Livewire\Home\Threads as HomeThreads;
use App\Livewire\Jobs;
use App\Livewire\Jobs\Create as JobsCreate;
use App\Livewire\Jobs\Single;
use App\Livewire\Message\Index as MessageIndex;
use App\Livewire\Message\View;
use App\Livewire\Notification;
use App\Livewire\ReportViolation;
use App\Livewire\SiteTools\Index as SiteToolsIndex;
use App\Livewire\Thread\Create;
use App\Livewire\Thread\Edit;
use App\Livewire\Thread\Index;
use App\Livewire\User\EditProfile;
use App\Livewire\User\EditProfile\Email;
use App\Livewire\User\EditProfile\Feedback;
use App\Livewire\User\EditProfile\Password;
use App\Livewire\User\EditProfile\Premium;
use App\Livewire\User\Profile;
use Illuminate\Support\Facades\Auth;


/*
|--------------------------------------------------------------------------
| Web Routes
|--------------------------------------------------------------------------
|
| Here is where you can register web routes for your application. These
| routes are loaded by the RouteServiceProvider and all of them will
| be assigned to the "web" middleware group. Make something great!
|
*/

// Route::domain('{blogname}.' . config('app.short_url'))->group(function(){
//     Route::get('/', function(){
//         return 'anasayfa';
//     });

//     Route::get('/{id}', function(){
//         return 'yazı id';
//     });

//     Route::get('/c/{id}', function(){
//         return 'kategori id';
//     });
// });

Route::get('/', HomeThreads::class)->name('home');
Route::get('@{username}', Profile::class)->name('user-profile');
Route::get('/c/{slug}', Threads::class)->name('category');
Route::get('/t/{slug}', Index::class)->name('thread');
Route::get('/categories', [CategoryController::class, 'index'])->name('categories');
Route::get('/report-violation', ReportViolation::class)->name('report-violation');
Route::get('/changelog', Changelogs::class)->name('changelog');


Route::name('jobs.')->prefix('jobs')->group(function(){
    Route::get('/', Jobs::class)->name('index');
    Route::get('/create', JobsCreate::class)->name('create')->middleware([AuthCheck::class]);
    Route::get('/{slug}', Single::class)->name('single');
});

Route::prefix('thread')
    ->middleware([AuthCheck::class])
    ->group(function () {
        Route::get('/new', Create::class)->name('new-thread');
        Route::get('/edit/{id}', Edit::class)->name('edit-thread');
});

Route::middleware([AuthCheck::class])->group(function () {
    Route::name('edit-profile.')->prefix('edit-profile')->group(function(){
        Route::get('/', EditProfile::class)->name('index');
        Route::get('/email', Email::class)->name('email');
        Route::get('/password', Password::class)->name('password');
        // Route::get('/premium', Premium::class)->name('premium');
        Route::get('/feedback', Feedback::class)->name('feedback');
    });

    // Logout
    Route::get('/logout', function(){
        Auth::logout();
        return redirect()->route('home');
    });

    Route::get('/favorites', Favorites::class)->name('favorites');

    Route::post('/upload', [TrixController::class, 'upload']);
    Route::post('/store', [TrixController::class, 'store']);;

    Route::name('messages.')->prefix('message')->group(function(){
        Route::get('/', MessageIndex::class)->name('index');
        Route::get('/{id}', View::class)->name('view');
    });

    Route::get('/notifications', Notification::class)->name('notifications');
});

Route::name('dashboard.')->prefix('dashboard')->group(function(){
    Route::get('/', DashboardIndex::class)->name('index')->middleware([PremiumIsValid::class]);

    Route::middleware([isAdmin::class])->group(function(){
        Route::get('/settings', Settings::class)->name('settings');
        Route::get('/users', Users::class)->name('users');
        Route::get('/user/{id}', EditUser::class)->name('edit-user');
        Route::get('/reports', Abuse::class)->name('reports');
        Route::get('/feedback', DashboardFeedback::class)->name('feedback');
        Route::get('/ads/{tab?}', Ad::class)->name('ads');
        Route::get('/categories', Category::class)->name('categories');
        Route::get('/categories/edit/{id}', EditCategory::class)->name('edit-category');
        Route::get('/job-categories', JobCategory::class)->name('job-categories');
        Route::get('/job-categories/edit/{id}', EditJobCategory::class)->name('edit-job-category');
        Route::get('/comments', Comments::class)->name('comments');
    });
});

// Route::name('tools.')->prefix('site-tools')->group(function(){
//     Route::get('/', SiteToolsIndex::class)->name('index');
// });
